@@ -67,6 +67,10 @@ else:
         fullname = os.path.join(os.environ.get("MAGPLUS_HOME", ""), "lib/libMagPlus.so")
         if os.path.exists(fullname):
             lib = fullname
+        else:
+            fullname = os.path.join(os.environ.get("MAGPLUS_HOME", ""), "lib64/libMagPlus.so")
+            if os.path.exists(fullname):
+                lib = fullname
 
 
 #
